API
======

.. automodule:: pysftp
   :members:


SFTPAttributes
--------------
see http://paramiko-docs.readthedocs.org/en/latest/api/sftp.html?highlight=sftpattributes#paramiko.sftp_attr.SFTPAttributes for details

SFTPFile
--------
see http://paramiko-docs.readthedocs.org/en/latest/api/sftp.html?highlight=paramiko.sftp_file.sftpfile#paramiko.sftp_file.SFTPFile for details


SecurityOptions
---------------
a simple object returned with available Security Options

see http://paramiko-docs.readthedocs.org/en/latest/api/transport.html?highlight=ciphers#paramiko.transport.SecurityOptions for details